/*
 * Asterisk -- An open source telephony toolkit.
 *
 * Copyright (C) 1999 - 2005, Digium, Inc.
 *
 * Mark Spencer <markster@digium.com>
 *
 * See http://www.asterisk.org for more information about
 * the Asterisk project. Please do not directly contact
 * any of the maintainers of this project for assistance;
 * the project provides a web site, mailing lists and IRC
 * channels for your use.
 *
 * This program is free software, distributed under the terms of
 * the GNU General Public License Version 2. See the LICENSE file
 * at the top of the source tree.
 */

/*! \file
 *
 * \brief App to transmit a message from gsm module
 *
 * \author Atcom
 * 
 * \note Requires support of sending  messages from  channel driver
 *
 * \ingroup applications
 */
 
#include "asterisk.h"

ASTERISK_FILE_VERSION(__FILE__, "$Revision: 187366 $")

#include <sys/ioctl.h>
#include "asterisk/file.h"
#include "asterisk/channel.h"
#include "asterisk/pbx.h"
#include "asterisk/module.h"
#include "asterisk/app.h"

/*! The timeout for send sms, in seconds */

/*** DOCUMENTATION
	<application name="Sendsms" language="en_US">
		<synopsis>
			Send a Text Message from GSM module.
		</synopsis>
		<syntax>
			<parameter name="text" required="true" />
		</syntax>
		<description>
			<para>Sends <replaceable>text</replaceable> to dahdii(gsm) channel (callee).</para>
			<para>Result of transmission will be stored in the <variable>SENDSMSSTATUS</variable></para>
			<variablelist>
				<variable name="SENDSMSSTATUS">
					<value name="SUCCESS">
						Transmission succeeded.
					</value>
					<value name="FAILURE">
						Transmission failed.
					</value>
				</variable>
			</variablelist>
			<note><para>At this moment, text is supposed to be 7 bit ASCII in most channels.</para></note>
		</description>
		<see-also>
			<ref type="application">Sendsms</ref>
			<ref type="application">SendImage</ref>
			<ref type="application">SendURL</ref>
		</see-also>
	</application>
 ***/

static const char *app = "SendSms";

static int sendsms_exec(struct ast_channel *chan, char *data)
{
    char *status = "FAILURE";

	if (!data) {
		ast_log(LOG_WARNING, "Sendsms requires an argument (text)\n");
		return -1;
	} 


   if (ast_sendtext(chan, data)) {
        status = "SUCCESS";
    }

	pbx_builtin_setvar_helper(chan, "SENDSMSSTATUS", status);

	return 0;
}

static int unload_module(void)
{
	return ast_unregister_application(app);
}

static int load_module(void)
{
	return ast_register_application_xml(app, sendsms_exec);
}

AST_MODULE_INFO_STANDARD(ASTERISK_GPL_KEY, "Send sms Applications");
