/*
 * Asterisk -- An open source telephony toolkit.
 *
 * Copyright (C) 2005 - 2006, Digium, Inc.
 *
 * Russell Bryant <russell@digium.com>
 *
 * See http://www.asterisk.org for more information about
 * the Asterisk project. Please do not directly contact
 * any of the maintainers of this project for assistance;
 * the project provides a web site, mailing lists and IRC
 * channels for your use.
 *
 * This program is free software, distributed under the terms of
 * the GNU General Public License Version 2. See the LICENSE file
 * at the top of the source tree.
 */

/*!
 * \file
 * \author atcom
 *
 * \brief Send sms via the CLI
 *
 */

#include "asterisk.h"

ASTERISK_FILE_VERSION(__FILE__, "$Revision: 196758 $");

#include "asterisk/channel.h"
#include "asterisk/pbx.h"
#include "asterisk/module.h"
#include "asterisk/cli.h"
#include "asterisk/utils.h"
#include "asterisk/frame.h"

    
/*!
 * \brief send a sms from the CLI
 * \param fd file descriptor for cli
 * \param chan channel to create type/data
 * \param app application you want to run
 * \param appdata data for application
 * \retval CLI_SUCCESS on success.
 * \retval CLI_SHOWUSAGE on failure.
*/

static char *sendsms(int fd, const char *chan, const char *appdata)
{
	char *chantech;
	char *chandata;
    int timeout = 3000;
    char *app = "Sendsms";

	if (ast_strlen_zero(appdata))
		return CLI_SHOWUSAGE;

	chandata = ast_strdupa(chan);

	chantech = strsep(&chandata, "/");
	if (!chandata) {
		ast_cli(fd, "*** No data provided after channel type! ***\n");
		return CLI_SHOWUSAGE;
	}

    ast_pbx_runing_app(chantech, AST_FORMAT_SLINEAR, chandata, timeout, app, appdata); 

	return CLI_SUCCESS;
}


/*!
 * \brief handle for send out.
 * \param e pointer to the CLI structure to initialize
 * \param cmd operation to execute
 * \param a structure that contains either application or extension arguments
 * \retval CLI_SUCCESS on success.
 * \retval CLI_SHOWUSAGE on failure.*/
static char *handle_sendsms(struct ast_cli_entry *e, int cmd, struct ast_cli_args *a)
{
    char *res = NULL;
    int i;
    char tmp[256];
    char data[256];
	switch (cmd) {
	case CLI_INIT:
		e->command = "sendsms";
		e->usage =
			"	 A sms can be send by a channel, This is similar to sendtext\n"
			"	Usage: sendsms <dahdi/id>  phone  message\n";
		return NULL;
	case CLI_GENERATE:
		return NULL;
	}

	if (ast_strlen_zero(a->argv[1]) || ast_strlen_zero(a->argv[2])) 
		return CLI_SHOWUSAGE;

	/* ugly, can be removed when CLI entries have ast_module pointers */
	ast_module_ref(ast_module_info->self);

    strncpy(data, a->argv[2], sizeof(data));

    for (i=3; i<a->argc; i++){
        if (strlen(data) >= sizeof(data)) 
            break;
        strcpy(tmp, data);
        snprintf(data, sizeof(data), "%s %s", tmp, a->argv[i]);
    }

	if (!strncasecmp("dahdi", a->argv[1], 5)) 
		res = sendsms(a->fd, a->argv[1], data);
	else 
		res = CLI_SHOWUSAGE;

	ast_module_unref(ast_module_info->self);

	return res;
}


static struct ast_cli_entry cli_sendsms[] = {
	AST_CLI_DEFINE(handle_sendsms, "Send a sms"),
};

static int unload_module(void)
{
	return ast_cli_unregister_multiple(cli_sendsms, ARRAY_LEN(cli_sendsms));
}

static int load_module(void)
{
	int res;
	res = ast_cli_register_multiple(cli_sendsms, ARRAY_LEN(cli_sendsms));
	return res ? AST_MODULE_LOAD_DECLINE : AST_MODULE_LOAD_SUCCESS;
}

AST_MODULE_INFO_STANDARD(ASTERISK_GPL_KEY, "Send a sms via the CLI");
